@@ -5,7 +5,7 @@ use strict;
 use 5.008003;
 no warnings 'utf8';
 
-our $VERSION = '0.074';
+our $VERSION = '0.075';
 use Exporter 'import';
 our @EXPORT_OK = qw( print_table );
 
@@ -20,19 +20,6 @@ use Term::Choose::Util            qw( term_size insert_sep unicode_sprintf );
 use Term::TablePrint::ProgressBar qw();
 
 
-my $Plugin;
-BEGIN {
-    if ( $^O eq 'MSWin32' ) {
-        require Term::Choose::Win32;
-        $Plugin = 'Term::Choose::Win32';
-    }
-    else {
-        require Term::Choose::Linux;
-        $Plugin = 'Term::Choose::Linux';
-    }
-}
-
-
 sub new {
     my $class = shift;
     croak "new: called with " . @_ . " arguments - 0 or 1 arguments expected." if @_ > 1;
@@ -43,14 +30,13 @@ sub new {
         $self->__validate_options( $opt );
     }
     $self->{backup_opt} = { defined $opt ? %$opt : () };
-    $self->{plugin} = $Plugin->new();
     return $self;
 }
 
 
 sub DESTROY {
     my ( $self ) = @_;
-    $self->{plugin}->__show_cursor();
+    print SHOW_CURSOR if $^O ne 'MSWin32';
 }
 
 
@@ -114,7 +100,7 @@ sub __set_defaults {
 
 sub print_table {
     if ( ref $_[0] ne 'Term::TablePrint' ) {
-        return print_table( bless( { plugin => $Plugin->new() }, 'Term::TablePrint' ), @_ );
+        return print_table( bless( {}, 'Term::TablePrint' ), @_ );
     }
     my $self = shift;
     my ( $table_ref, $opt ) = @_;
@@ -140,7 +126,8 @@ sub print_table {
     else {
         $self->{idx_last_row} = $#$table_ref;
     }
-    $self->{plugin}->__hide_cursor();
+    local $| = 1;
+    print HIDE_CURSOR if $^O ne 'MSWin32';
     my $col_idxs = [];
     if ( $self->{choose_columns}  ) {
         $col_idxs = $self->__choose_columns( $table_ref->[0] );
@@ -156,8 +143,7 @@ sub print_table {
     $self->{binray_regexp} = qr/[\x00-\x08\x0B-\x0C\x0E-\x1F]/;
     $self->{show_progress} = 0;
     if ( $self->{progress_bar} ) {
-        local $| = 1;
-        $self->{plugin}->__clear_screen();
+        print CLEAR_SCREEN if $^O ne 'MSWin32';
         print 'Computing:';
         $self->{show_progress} = int @$a_ref * @{$a_ref->[0]} / $self->{progress_bar};
     }
@@ -166,7 +152,7 @@ sub print_table {
     if ( exists $self->{backup_opt} ) {
         my $backup_opt = $self->{backup_opt};
         for my $key ( keys %$self ) {
-            if ( $key eq 'plugin' || $key eq 'backup_opt' ) {
+            if ( $key eq 'backup_opt' ) {
                 next;
             }
             elsif ( exists $backup_opt->{$key} ) {
@@ -177,7 +163,7 @@ sub print_table {
             }
         }
     }
-    $self->{plugin}->__show_cursor();
+    print SHOW_CURSOR if $^O ne 'MSWin32';
 }
 
 
@@ -619,7 +605,7 @@ Term::TablePrint - Print a table to the terminal and browse it interactively.
 
 =head1 VERSION
 
-Version 0.074
+Version 0.075
 
 =cut
 
